#!/bin/sh
#
# Copyright (c) 2007, 2008  Peter Pentchev
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the distribution.
#
# THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
# FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
# DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
# OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
# HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
# OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.
#
# $Ringlet: trivbackup_mysql.sh 1785 2008-01-31 12:58:32Z roam $

usage()
{
	echo 'Usage: trivbackup_mysql backuppath' 1>&2
}

# TODO: Parse the command-line options (-h, -V, -f conffile)

# Read the config file
CONFFILE='/etc/trivbackup.conf'
if [ ! -r "${CONFFILE}" ]; then
	echo "Unable to read configuration file $CONFFILE" 1>&2
	exit 1
fi

. "${CONFFILE}"

# Process the rest of the command-line arguments
if [ "$#" -ne 1 ]; then
	usage
	exit 1
fi
MYSQLBACKUPDIR="$1"

if [ ! -d "$MYSQLBACKUPDIR" ]; then
	echo "The backup directory $MYSQLBACKUPDIR does not exist" 1>&2
	exit 1
fi
if [ ! -w "$MYSQLBACKUPDIR" ]; then
	echo "The backup directory $MYSQLBACKUPDIR is not writeable" 1>&2
	exit 1
fi

# Let's rock!

D=`date '+%Y%m%d%H%M'`

exitcode=0

# Backup all the MySQL databases

${MYSQL} ${MYSQL_USER} -Ne 'show databases' | while read db; do
	f="${MYSQLBACKUPDIR}/$db-$D.sql"
	${MYSQLDUMP} ${MYSQL_USER} ${MYSQL_AUTH} ${MYSQLDUMP_ARGS} "$db" > "$f"
	if [ "$?" -ne 0 ]; then
		echo "MySQL backup: backing up '$db' to '$f' failed" 1>&2
		exitcode=1
	fi
	if [ -f "$f" ]; then
		${COMPRESS} ${COMPRESS_ARGS} "$f"
		if [ "$?" -ne 0 ]; then
			echo "MySQL backup: compressing '$f' failed" 1>&2
			exitcode=1
		fi
	fi
done

exit "$exitcode"
